@@ -12,7 +12,10 @@ options:
 
 """
 import sys
-import json
+try:
+    import ujson as json
+except ImportError:
+    import json
 
 from docopt import docopt
 from clint.textui import progress
@@ -54,7 +57,7 @@ def main(argv):
                 fp.write(metadata + '\n')
         else:
             try:
-                sys.stderr.write(metadata + '\n')
+                sys.stdout.write(metadata + '\n')
             except IOError:
                 break
     sys.exit(0)
